@@ -1,3 +1,4 @@
+from naas_drivers.input.awesomenotebook import AwesomeNotebooks
 from naas_drivers.input.yahoofinance import Yahoofinance
 from naas_drivers.input.cityfalcon import Cityfalcon
 from naas_drivers.input.geolocator import Geolocator
@@ -34,7 +35,7 @@ from naas_drivers.input.markdown import Markdown
 import requests
 import os
 
-__version__ = "0.42.3"
+__version__ = "0.48.10"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -51,7 +52,9 @@ sentiment = Sentiment()
 yahoofinance = Yahoofinance()
 pdf = Pdf()
 plotly = Plotly()
-emailBuilder = EmailBuilder()
+emailbuilder = EmailBuilder()
+emailBuilder = EmailBuilder(True)
+templates = AwesomeNotebooks()
 html = EmailBuilder(True)
 markdown = Markdown()
 teams = Teams()
